==> AgeOn1.7_source.zip: AgeOn1.7_source/nispi/Const/ConstProperty.cs <==
﻿//ライセンス情報はAgeOnフォルダのLISENCEフォルダを参照してください

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;

namespace nispi
{
    static partial class Const
    {
        public static Size MainFormType1Size
        {
            set
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                Const.InnerMainFormType1Size = value;

            }
            get
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                return Const.InnerMainFormType1Size;

            }
        }

        public static Size InnerMainFormType2Size;
        public static Size MainFormType2Size
        {
            set
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                Const.InnerMainFormType2Size = value;

            }
            get
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                return Const.InnerMainFormType2Size;

            }
        }

        public static Size InnerMapMainFormSize;
        public static Size MapMainFormSize
        {
            set
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                Const.InnerMapMainFormSize = value;

            }
            get
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                return Const.InnerMapMainFormSize;

            }
        }

        public static bool OnLine
        {
            set
            {
                mutex.WaitOne();
                Const.onLine = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                bool temp = Const.onLine;
                mutex.ReleaseMutex();
                return temp;

            }
        }

        public static string RoninSessionID
        {
            set
            {
                mutex.WaitOne();
                Const.roninSessionID = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                string temp = StrUtil.GetStrCopy(Const.roninSessionID);
                mutex.ReleaseMutex();
                return temp;
            }
        }
        public static bool RoninState
        {
            set
            {
                mutex.WaitOne();
                Const.roninState = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                bool temp = Const.roninState;
                mutex.ReleaseMutex();
                return temp;

            }
        }
    }
}

==> AgeOn2.5_source.zip: AgeOn2.5_source/nispi/Const/ConstProperty.cs <==
﻿//ライセンス情報はAgeOnフォルダのLISENCEフォルダを参照してください

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;

namespace nispi
{
    static partial class Const
    {
        public static Size MainFormType1Size
        {
            set
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                Const.InnerMainFormType1Size = value;

            }
            get
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                return Const.InnerMainFormType1Size;

            }
        }

        public static Size InnerMainFormType2Size;
        public static Size MainFormType2Size
        {
            set
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                Const.InnerMainFormType2Size = value;

            }
            get
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                return Const.InnerMainFormType2Size;

            }
        }
        public static Size InnerMainFormType3Size;
        public static Size MainFormType3Size
        {
            set
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                Const.InnerMainFormType3Size = value;

            }
            get
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                return Const.InnerMainFormType3Size;

            }
        }
        public static Size InnerMapMainFormSize;
        public static Size MapMainFormSize
        {
            set
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                Const.InnerMapMainFormSize = value;

            }
            get
            {
                mutex.WaitOne();
                mutex.ReleaseMutex();
                return Const.InnerMapMainFormSize;

            }
        }

        public static bool OnLine
        {
            set
            {
                mutex.WaitOne();
                Const.onLine = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                bool temp = Const.onLine;
                mutex.ReleaseMutex();
                return temp;

            }
        }

        public static string RoninSessionID
        {
            set
            {
                mutex.WaitOne();
                Const.roninSessionID = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                string temp = StrUtil.GetStrCopy(Const.roninSessionID);
                mutex.ReleaseMutex();
                return temp;
            }
        }
        public static bool RoninState
        {
            set
            {
                mutex.WaitOne();
                Const.roninState = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                bool temp = Const.roninState;
                mutex.ReleaseMutex();
                return temp;

            }
        }
    }
}
